@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,14 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
-from google.protobuf import duration_pb2 as gp_duration  # type: ignore
-from google.protobuf import struct_pb2 as struct  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-from google.type import money_pb2 as money  # type: ignore
+from google.protobuf import duration_pb2  # type: ignore
+from google.protobuf import struct_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+from google.type import money_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -62,65 +59,55 @@ class Recommendation(proto.Message):
             Examples: For recommender = "google.iam.policy.Recommender",
             recommender_subtype can be one of
             "REMOVE_ROLE"/"REPLACE_ROLE".
-        last_refresh_time (~.timestamp.Timestamp):
+        last_refresh_time (google.protobuf.timestamp_pb2.Timestamp):
             Last time this recommendation was refreshed
             by the system that created it in the first
             place.
-        primary_impact (~.recommendation.Impact):
+        primary_impact (google.cloud.recommender_v1beta1.types.Impact):
             The primary impact that this recommendation
             can have while trying to optimize for one
             category.
-        additional_impact (Sequence[~.recommendation.Impact]):
+        additional_impact (Sequence[google.cloud.recommender_v1beta1.types.Impact]):
             Optional set of additional impact that this
             recommendation may have when trying to optimize
             for the primary category. These may be positive
             or negative.
-        content (~.recommendation.RecommendationContent):
+        content (google.cloud.recommender_v1beta1.types.RecommendationContent):
             Content of the recommendation describing
             recommended changes to resources.
-        state_info (~.recommendation.RecommendationStateInfo):
+        state_info (google.cloud.recommender_v1beta1.types.RecommendationStateInfo):
             Information for state. Contains state and
             metadata.
         etag (str):
             Fingerprint of the Recommendation. Provides
             optimistic locking when updating states.
-        associated_insights (Sequence[~.recommendation.Recommendation.InsightReference]):
+        associated_insights (Sequence[google.cloud.recommender_v1beta1.types.Recommendation.InsightReference]):
             Insights that led to this recommendation.
     """
 
     class InsightReference(proto.Message):
         r"""Reference to an associated insight.
-
         Attributes:
             insight (str):
                 Insight resource name, e.g.
                 projects/[PROJECT_NUMBER]/locations/[LOCATION]/insightTypes/[INSIGHT_TYPE_ID]/insights/[INSIGHT_ID]
         """
 
-        insight = proto.Field(proto.STRING, number=1)
-
-    name = proto.Field(proto.STRING, number=1)
-
-    description = proto.Field(proto.STRING, number=2)
-
-    recommender_subtype = proto.Field(proto.STRING, number=12)
+        insight = proto.Field(proto.STRING, number=1,)
 
+    name = proto.Field(proto.STRING, number=1,)
+    description = proto.Field(proto.STRING, number=2,)
+    recommender_subtype = proto.Field(proto.STRING, number=12,)
     last_refresh_time = proto.Field(
-        proto.MESSAGE, number=4, message=timestamp.Timestamp,
+        proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,
     )
-
     primary_impact = proto.Field(proto.MESSAGE, number=5, message="Impact",)
-
     additional_impact = proto.RepeatedField(proto.MESSAGE, number=6, message="Impact",)
-
     content = proto.Field(proto.MESSAGE, number=7, message="RecommendationContent",)
-
     state_info = proto.Field(
         proto.MESSAGE, number=10, message="RecommendationStateInfo",
     )
-
-    etag = proto.Field(proto.STRING, number=11)
-
+    etag = proto.Field(proto.STRING, number=11,)
     associated_insights = proto.RepeatedField(
         proto.MESSAGE, number=14, message=InsightReference,
     )
@@ -131,7 +118,7 @@ class RecommendationContent(proto.Message):
     changing.
 
     Attributes:
-        operation_groups (Sequence[~.recommendation.OperationGroup]):
+        operation_groups (Sequence[google.cloud.recommender_v1beta1.types.OperationGroup]):
             Operations to one or more Google Cloud
             resources grouped in such a way that, all
             operations within one group are expected to be
@@ -145,9 +132,8 @@ class RecommendationContent(proto.Message):
 
 class OperationGroup(proto.Message):
     r"""Group of operations that need to be performed atomically.
-
     Attributes:
-        operations (Sequence[~.recommendation.Operation]):
+        operations (Sequence[google.cloud.recommender_v1beta1.types.Operation]):
             List of operations across one or more
             resources that belong to this group. Loosely
             based on RFC6902 and should be performed in the
@@ -199,16 +185,16 @@ class Operation(proto.Message):
             Can be set with action 'copy' or 'move' to indicate the
             source field within resource or source_resource, ignored if
             provided for other operation types.
-        value (~.struct.Value):
+        value (google.protobuf.struct_pb2.Value):
             Value for the ``path`` field. Will be set for
             actions:'add'/'replace'. Maybe set for action: 'test'.
             Either this or ``value_matcher`` will be set for 'test'
             operation. An exact match must be performed.
-        value_matcher (~.recommendation.ValueMatcher):
+        value_matcher (google.cloud.recommender_v1beta1.types.ValueMatcher):
             Can be set for action 'test' for advanced matching for the
             value of 'path' field. Either this or ``value`` will be set
             for 'test' operation.
-        path_filters (Sequence[~.recommendation.Operation.PathFiltersEntry]):
+        path_filters (Sequence[google.cloud.recommender_v1beta1.types.Operation.PathFiltersEntry]):
             Set of filters to apply if ``path`` refers to array elements
             or nested array elements in order to narrow down to a single
             unique element that is being tested/modified. This is
@@ -224,7 +210,7 @@ class Operation(proto.Message):
                "y@example.com"] }`` When both path_filters and
                path_value_matchers are set, an implicit AND must be
                performed.
-        path_value_matchers (Sequence[~.recommendation.Operation.PathValueMatchersEntry]):
+        path_value_matchers (Sequence[google.cloud.recommender_v1beta1.types.Operation.PathValueMatchersEntry]):
             Similar to path_filters, this contains set of filters to
             apply if ``path`` field referes to array elements. This is
             meant to support value matching beyond exact match. To
@@ -233,30 +219,21 @@ class Operation(proto.Message):
             AND must be performed.
     """
 
-    action = proto.Field(proto.STRING, number=1)
-
-    resource_type = proto.Field(proto.STRING, number=2)
-
-    resource = proto.Field(proto.STRING, number=3)
-
-    path = proto.Field(proto.STRING, number=4)
-
-    source_resource = proto.Field(proto.STRING, number=5)
-
-    source_path = proto.Field(proto.STRING, number=6)
-
+    action = proto.Field(proto.STRING, number=1,)
+    resource_type = proto.Field(proto.STRING, number=2,)
+    resource = proto.Field(proto.STRING, number=3,)
+    path = proto.Field(proto.STRING, number=4,)
+    source_resource = proto.Field(proto.STRING, number=5,)
+    source_path = proto.Field(proto.STRING, number=6,)
     value = proto.Field(
-        proto.MESSAGE, number=7, oneof="path_value", message=struct.Value,
+        proto.MESSAGE, number=7, oneof="path_value", message=struct_pb2.Value,
     )
-
     value_matcher = proto.Field(
         proto.MESSAGE, number=10, oneof="path_value", message="ValueMatcher",
     )
-
     path_filters = proto.MapField(
-        proto.STRING, proto.MESSAGE, number=8, message=struct.Value,
+        proto.STRING, proto.MESSAGE, number=8, message=struct_pb2.Value,
     )
-
     path_value_matchers = proto.MapField(
         proto.STRING, proto.MESSAGE, number=11, message="ValueMatcher",
     )
@@ -275,7 +252,7 @@ class ValueMatcher(proto.Message):
             to be used with RE2::FullMatch
     """
 
-    matches_pattern = proto.Field(proto.STRING, number=1, oneof="match_variant")
+    matches_pattern = proto.Field(proto.STRING, number=1, oneof="match_variant",)
 
 
 class CostProjection(proto.Message):
@@ -283,19 +260,18 @@ class CostProjection(proto.Message):
     save or incur.
 
     Attributes:
-        cost (~.money.Money):
+        cost (google.type.money_pb2.Money):
             An approximate projection on amount saved or
             amount incurred. Negative cost units indicate
             cost savings and positive cost units indicate
             increase. See google.type.Money documentation
             for positive/negative units.
-        duration (~.gp_duration.Duration):
+        duration (google.protobuf.duration_pb2.Duration):
             Duration for which this cost applies.
     """
 
-    cost = proto.Field(proto.MESSAGE, number=1, message=money.Money,)
-
-    duration = proto.Field(proto.MESSAGE, number=2, message=gp_duration.Duration,)
+    cost = proto.Field(proto.MESSAGE, number=1, message=money_pb2.Money,)
+    duration = proto.Field(proto.MESSAGE, number=2, message=duration_pb2.Duration,)
 
 
 class Impact(proto.Message):
@@ -303,9 +279,9 @@ class Impact(proto.Message):
     category.
 
     Attributes:
-        category (~.recommendation.Impact.Category):
+        category (google.cloud.recommender_v1beta1.types.Impact.Category):
             Category that is being targeted.
-        cost_projection (~.recommendation.CostProjection):
+        cost_projection (google.cloud.recommender_v1beta1.types.CostProjection):
             Use with CategoryType.COST
     """
 
@@ -318,7 +294,6 @@ class Impact(proto.Message):
         MANAGEABILITY = 4
 
     category = proto.Field(proto.ENUM, number=1, enum=Category,)
-
     cost_projection = proto.Field(
         proto.MESSAGE, number=100, oneof="projection", message="CostProjection",
     )
@@ -326,12 +301,11 @@ class Impact(proto.Message):
 
 class RecommendationStateInfo(proto.Message):
     r"""Information for state. Contains state and metadata.
-
     Attributes:
-        state (~.recommendation.RecommendationStateInfo.State):
+        state (google.cloud.recommender_v1beta1.types.RecommendationStateInfo.State):
             The state of the recommendation, Eg ACTIVE,
             SUCCEEDED, FAILED.
-        state_metadata (Sequence[~.recommendation.RecommendationStateInfo.StateMetadataEntry]):
+        state_metadata (Sequence[google.cloud.recommender_v1beta1.types.RecommendationStateInfo.StateMetadataEntry]):
             A map of metadata for the state, provided by
             user or automations systems.
     """
@@ -346,8 +320,7 @@ class RecommendationStateInfo(proto.Message):
         DISMISSED = 5
 
     state = proto.Field(proto.ENUM, number=1, enum=State,)
-
-    state_metadata = proto.MapField(proto.STRING, proto.STRING, number=2)
+    state_metadata = proto.MapField(proto.STRING, proto.STRING, number=2,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
